@@ -11,6 +11,31 @@
 #' xfun::attr(z, 'foo')  # 2
 attr = function(...) base::attr(..., exact = TRUE)
 
+#' Set the global option \code{\link{options}(stringsAsFactors = FALSE)} inside
+#' a parent function and restore the option after the parent function exits
+#'
+#' This is a shorthand of \code{opts = options(stringsAsFactors = FALSE);
+#' on.exit(options(opts), add = TRUE)}; \code{strings_please()} is an alias of
+#' \code{stringsAsStrings()}.
+#' @export
+#' @examples
+#' f = function() {
+#' xfun::strings_please()
+#' data.frame(x = letters[1:4], y = factor(letters[1:4]))
+#' }
+#' str(f())  # the first column should be character
+stringsAsStrings = function() {
+  opts = options(stringsAsFactors = FALSE)
+  do.call(
+    on.exit, list(substitute(options(x), list(x = opts)), add = TRUE),
+    envir = parent.frame()
+  )
+}
+
+#' @rdname stringsAsStrings
+#' @export
+strings_please = stringsAsStrings
+
 #' Evaluate an expression under a specified working directory
 #'
 #' Change the working directory, evaluate the expression, and restore the
@@ -160,13 +185,11 @@ gsubi = function(...) gsub(..., ignore.case = TRUE)
 download_file = function(url, output = basename(url), ...) {
   if (missing(output)) output = gsub('[?#].*$', '', output)  # remove query/hash
   download = function(method = 'auto') download.file(url, output, ..., method = method)
-  if (is_windows()) for (method in c('libcurl', 'wininet', 'auto')) {
+  for (method in c('libcurl', if (is_windows()) 'wininet', 'auto')) {
     if (!inherits(try_silent(res <- download(method = method)), 'try-error') && res == 0)
       return(res)
   }
 
-  R340 = getRversion() >= '3.4.0'
-  if (R340 && download() == 0) return(0L)
   # check for libcurl/curl/wget/lynx, call download.file with appropriate method
   res = NA
   if (Sys.which('curl') != '') {
@@ -181,7 +204,7 @@ download_file = function(url, output = basename(url), ...) {
   if (Sys.which('lynx') != '') {
     if ((res <- download(method = 'lynx')) == 0) return(res)
   }
-  if (is.na(res)) stop('No download method found (auto/wininet/wget/curl/lynx)')
+  if (is.na(res)) stop('No download method works (auto/wininet/wget/curl/lynx)')
 
   res
 }
